@@ -1,5 +1,5 @@
 "principal" <-
-function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median") {
+function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,missing=FALSE,impute="median",oblique.scores=TRUE) {
    cl <- match.call()
    n <- dim(r)[2]
   
@@ -112,8 +112,11 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, scores=FALSE,
     result$PVAL <-  stats$PVAL
     result$weights <-  stats$weights
     result$r.scores <-  stats$r.scores
+    if(!is.null(Phi) && oblique.scores) {
+                       Structure <- loadings %*% Phi} else {Structure <- loadings
+                       }
     
-    if(scores) {result$scores <- factor.scores(scale(x.matrix),loadings) }
+    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure) }
     return(result)
    }
   
